
import com.persagy.database.SGroup
import com.persagy.service.models.SCascadeQuery
import io.swagger.annotations.ApiModel
import io.swagger.annotations.ApiModelProperty

/**
 * 查询请求对象基类
 *
 * @author  庞利祥 <sybotan@126.com>
 */
@ApiModel(description = "查询请求对象基类")
open class SQueryRequest {
    companion object {
        /** 设置接口一次可取得的最大记录数 */
        var maxRow = 1000
    } // Companion object

    /** 第几页 */
    @ApiModelProperty(value = "第几页(从1开始)", example = "1")
    var pageNumber: Int = 1
        set(value) {            // 限定pageNumber不能小于1
            field = value
            if (value < 1) {
                field = 1
            }
        }

    /** 每页记录数 */
    @ApiModelProperty(value = "每页记录数(0 < 记录数 < 1000)", example = "50")
    var pageSize: Int = 50
        set(value) {            // 限定pageSize不能小于1且不能大于maxRow
            field = value
            if (value < 1 ) {
                field = 1
            }
            if (value > maxRow) {
                field = maxRow
            }
            // maxRow一次设置有效，之后将自动设备为1000
            maxRow = 1000
        }

    /** 查询条件 */
    @ApiModelProperty(value = "查询条件")
    var filters: String? = null

    /** 排序条件 */
    @ApiModelProperty(value = "排序条件", example = "name asc, createTime desc")
    var orders: String? = null

    /** 去除重复记录 */
    @ApiModelProperty(value = "去除重复记录")
    var distinct: Boolean? = null

    /** 字段影射，空为查询所有字段 */
    @ApiModelProperty(value = "字段影射，空为查询所有字段")
    var projection: ArrayList<String>? = null

    /** 级联对象列表 */
    @ApiModelProperty(value = "级联对象列表")
    var cascade: ArrayList<SCascadeQuery>? = null

    /** 分组统计 */
    @ApiModelProperty(value = "分组")
    var group: SGroup? = null
} // Class SQueryRequest