---
sidebarDepth: 2
---
# 标签

::: details 目录
[[toc]]
:::

https://docs.oracle.com/javase/8/docs/technotes/tools/windows/javadoc.html
## 标签
### @author
----

作者。用于类和接口注释。可有零到多个。

**语法：**
```
@author name-text
```

**参数：**

* *name-text*

&emsp;&emsp;    作者。

**示例：**

一个作者
```typescript {4}
/**
 * 点数据类型定义
 *
 * @author 庞利祥 <sybotan@126.com>
 */
export class SPoint {
    //
}
```

多个作者
```typescript {4,5}
/**
 * 点数据类型定义
 *
 * @author 庞利祥 <sybotan@126.com>
 * @author 庞凌峰 <sandy@126.com>
 */
export class SPoint {
    //
}
```

### @deprecated
----
废除标志。标识过期API（为了保证兼容性，仍可用，但不推荐用）。最多一个。

**语法：**
```
@deprecated deprecated-text
```

**参数：**
* *deprecated-text*

&emsp;&emsp;    废除的原因。

**示例：**
```typescript{5,14}
/**
 * 点数据类型定义
 *
 * @author 庞利祥 <sybotan@126.com>
 * @deprecated  使用 SPoint 类代替。
 */
export class SPointF {

    /**
     * 平移点
     *
     * @param dx    X 轴位移
     * @param dy    Y 轴位移
     * @deprecated  不在支持
     */
    translate(dx: number, dy: number): void {
        this.x += dx;
        this.y += dy;
    }
}
```

### @exception 或 @throws
----

标识函数会抛出异常。

**语法：**
```
@exception  class-name  description
```
或
```
@throws  class-name  description
```


**参数：**

* *class-name*

&emsp;&emsp;    抛出的异常类。

* *description*

&emsp;&emsp;    异常描述。

**示例：**
```typescript

```


### @param
----
函数入参。

**语法：**
```
@param  parameter-name description
```

**参数：**

* *parameter-name*

&emsp;&emsp;    参数名。

* *description*

&emsp;&emsp;    参数描述。

**示例：**

函数入参

```typescript {5,6}
export class S {
    /**
     * 平移矩形
     *
     * @param   dx      x 轴位移
     * @param   dy      y 轴位移
     */
    translate(dx: number, dy: number): void {
        this.x += dx;
        this.y += dy;
    }
}
```

构造函数入参

```typescript {5-8}
export class SRect {
    /**
     * 构造函数
     *
     * @param   x           x 轴坐标
     * @param   y           y 轴坐标
     * @param   width       宽度
     * @param   height      高度
     */
    constructor(x: number, y: number, width: number, height: number) {
    }
}
```

带泛型的函数
```typescript {4,5}
/**
 * 返回对象的标识符
 *
 * @param   <T>     泛型类型
 * @param   arg     入参
 */
function identity<T>(arg: T): T {
    return arg;
}
```

### @return
----
函数返回值描述。

**语法：**
```
@return  description
```

**参数：**

* *description*

&emsp;&emsp;    返回值描述。

**示例：**
```typescript{5}
/**
 * 旋转变形
 *
 * @param   angle       绕 z 轴旋转角度（单位角度）
 * @return  返回自身
 */
rotate(angle: number): SMatrix {
    ......
    return matirx;
}
```

### @see
----

**语法：**
```
@see  reference
```

**参数：**

* *reference*

&emsp;&emsp;    参考对象。

**示例：**
```typescript

```

### @serial
----

**语法：**
```
@serial  field-description | include | exclude
```

**参数：**

**示例：**
```typescript

```

### @serialField
----

**语法：**
```
@serialField  field-name  field-type  field-description
```

**参数：**

**示例：**
```typescript

```

### @serialData
----

**语法：**
```
@serialData  data-description
```

**参数：**

**示例：**
```typescript

```

### @since
----

**语法：**
```
@since  since-text
```

**参数：**

* *since-text*

&emsp;&emsp;    起始版本。

**示例：**
```typescript
/**
 * @since   1.0.0
 */
export class SObject {
    //
}
```

### @version
----
版本号。

**语法：**
```kotlin
@version  version-text
```

**参数：**

* *version-text*

&emsp;&emsp;    版本号。

**示例：**
```typescript{2}
/**
 * @version 2.2.56
 */
export class SObject {
    //
}
```

### {@code text}
----

### {@docRoot}
----

### {@inheritDoc}
----

### {@link package.class#member label}
----

### {@linkplain package.class#member label}
----

### {@literal text}
----

### {@value package.class#field}
----

## 用途
### Overview Tags
@see reference || @since since-text || @serialField field-name field-type field-description || @author name-text || @version version-text || {@link package.class#member label} || {@linkplain package.class#member label} || {@docRoot}

### Package Tags
@see reference || @since since-text || @serial field-description | include | exclude || @author name-text || @version version-text || {@linkplain package.class#member label} || {@linkplain package.class#member label} || {@docRoot}

### Class and Interface Tags
@see reference || @since since-text || @deprecated deprecated-text || @serial field-description | include | exclude || @author name-text || @version version-text || {@link package.class#member label} || {@linkplain package.class#member label} || {@docRoot}

### Field Tags
@see reference || @since since-text || @deprecated deprecated-text || @serial field-description | include | exclude || @serialField field-name field-type field-description || {@link package.class#member label} || {@linkplain package.class#member label} || {@docRoot} || {@value package.class#field}

### Constructor and Method Tags
@see reference || @since since-text || @deprecated deprecated-text || @param parameter-name description || @return description || @throws class-name description || @exception class-name description || @serialData data-description || {@link package.class#member label} || {@linkplain package.class#member label} || {@inheritDoc} || {@docRoot}
